package com.ruoyi.model.controller;

import java.io.IOException;
import java.util.List;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.model.domain.AppPlatformAgreementConfig;
import com.ruoyi.model.service.IAppPlatformAgreementConfigService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 平台协议配置Controller
 * 
 * @author ruoyi
 * @date 2025-03-08
 */
@RestController
@RequestMapping("/model/AppPlatformAgreementConfig")
public class AppPlatformAgreementConfigController extends BaseController
{
    @Autowired
    private IAppPlatformAgreementConfigService appPlatformAgreementConfigService;

    /**
     * 查询平台协议配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppPlatformAgreementConfig:list')")
    @GetMapping("/list")
    public TableDataInfo list(AppPlatformAgreementConfig appPlatformAgreementConfig)
    {
        startPage();
        List<AppPlatformAgreementConfig> list = appPlatformAgreementConfigService.selectAppPlatformAgreementConfigList(appPlatformAgreementConfig);
        return getDataTable(list);
    }

    /**
     * 导出平台协议配置列表
     */
    @PreAuthorize("@ss.hasPermi('model:AppPlatformAgreementConfig:export')")
    @Log(title = "平台协议配置", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, AppPlatformAgreementConfig appPlatformAgreementConfig) throws IOException {
        List<AppPlatformAgreementConfig> list = appPlatformAgreementConfigService.selectAppPlatformAgreementConfigList(appPlatformAgreementConfig);
        ExcelUtil<AppPlatformAgreementConfig> util = new ExcelUtil<AppPlatformAgreementConfig>(AppPlatformAgreementConfig.class);
        util.exportExcel(response, list, "平台协议配置数据");
    }

    /**
     * 获取平台协议配置详细信息
     */
    @PreAuthorize("@ss.hasPermi('model:AppPlatformAgreementConfig:query')")
    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(appPlatformAgreementConfigService.selectAppPlatformAgreementConfigById(id));
    }

    /**
     * 新增平台协议配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppPlatformAgreementConfig:add')")
    @Log(title = "平台协议配置", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody AppPlatformAgreementConfig appPlatformAgreementConfig)
    {
        return toAjax(appPlatformAgreementConfigService.insertAppPlatformAgreementConfig(appPlatformAgreementConfig));
    }

    /**
     * 修改平台协议配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppPlatformAgreementConfig:edit')")
    @Log(title = "平台协议配置", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody AppPlatformAgreementConfig appPlatformAgreementConfig)
    {
        return toAjax(appPlatformAgreementConfigService.updateAppPlatformAgreementConfig(appPlatformAgreementConfig));
    }

    /**
     * 删除平台协议配置
     */
    @PreAuthorize("@ss.hasPermi('model:AppPlatformAgreementConfig:remove')")
    @Log(title = "平台协议配置", businessType = BusinessType.DELETE)
	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(appPlatformAgreementConfigService.deleteAppPlatformAgreementConfigByIds(ids));
    }
}
